# Entity Label

Often times a declarative statement about an entity may need to transform based on the bundle type. For example, Bobby
posted an idea about quick brown foxes. Imagine idea is the bundle type. This module provides translatable label
configurations, available on the bundle type form, for any bundle-enabled entity type.

## Usage

1. Download and install the `drupal/entity_label` module. Recommended install method is composer:
   ```
   composer require drupal/entity_label
   ```
2. Edit the desired entity bundle type. For instance, a node content type.
3. Open the "Label settings" section and configure as needed.
4. Render labels using one or more of the provided methods.

## Callable PHP function

```php
t('Bobby posted @label about @title.', [
  '@label' => entity_label($entity, 'definite_article'),
  '@title' => $entity->label(),
]);
```

## Twig extension

```twig
{% set label = entity_label(entity, 'definite_article') %}
{% trans %}
  Bobby posted {{ label }} about {{ entity.label() }}.
{% endtrans %}
```

## Replacement tokens

Use the token browser to discover and insert available token replacements. Or use the following examples:

- `[ENTITY_TYPE:label:singular]`
- `[ENTITY_TYPE:label:singular-definite-article]`
- `[ENTITY_TYPE:label:plural]`

> **NOTE:** Replace `ENTITY_TYPE` with the entity bundle type machine name.
